Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type IdentificationServiceArea ¶
type IdentificationServiceArea struct {
ID dssmodels.ID
URL string
Owner dssmodels.Owner
Cells s2.CellUnion
StartTime *time.Time
EndTime *time.Time
Version *dssmodels.Version
AltitudeHi *float32
AltitudeLo *float32
}
IdentificationServiceArea represents a USS ISA over a given 4D volume.
func (*IdentificationServiceArea) AdjustTimeRange ¶
func (i *IdentificationServiceArea) AdjustTimeRange(now time.Time, old *IdentificationServiceArea) error
AdjustTimeRange adjusts the time range to the max allowed ranges on a IdentificationServiceArea.
func (*IdentificationServiceArea) SetExtents ¶
func (i *IdentificationServiceArea) SetExtents(extents *ridpb.Volume4D) error
SetExtents performs some data validation and sets the 4D volume on the IdentificationServiceArea.
func (*IdentificationServiceArea) ToProto ¶
func (i *IdentificationServiceArea) ToProto() (*ridpb.IdentificationServiceArea, error)
ToProto converts an IdentificationServiceArea struct to an IdentificationServiceArea proto for API consumption.
type Subscription ¶
type Subscription struct {
ID dssmodels.ID
URL string
NotificationIndex int
Owner dssmodels.Owner
Cells s2.CellUnion
StartTime *time.Time
EndTime *time.Time
Version *dssmodels.Version
AltitudeHi *float32
AltitudeLo *float32
}
Subscription represents a USS subscription over a given 4D volume.
func (*Subscription) AdjustTimeRange ¶
func (s *Subscription) AdjustTimeRange(now time.Time, old *Subscription) error
AdjustTimeRange adjusts the time range to the max allowed ranges on a subscription.
func (*Subscription) SetExtents ¶
func (s *Subscription) SetExtents(extents *ridpb.Volume4D) error
SetExtents performs some data validation and sets the 4D volume on the Subscription.
func (*Subscription) ToNotifyProto ¶
func (s *Subscription) ToNotifyProto() *ridpb.SubscriberToNotify
ToNotifyProto converts a subscription to a SubscriberToNotify proto for API consumption.
func (*Subscription) ToProto ¶
func (s *Subscription) ToProto() (*ridpb.Subscription, error)
ToProto converts a subscription struct to a Subscription proto for API consumption.